# Tcl package index file, version 1.0

package ifneeded Tk 8.2 [list load [file join $dir libtk8.2.a] Tk]
package ifneeded Tksquare 8.2 [list tclPkgSetup $dir Tksquare 8.2\
    [list [list Tksquare[info sharedlibextension] load square]]]
package ifneeded Tktest 8.2 [list tclPkgSetup $dir Tktest 8.2\
    [list [list Tktest[info sharedlibextension] load {testclipboard testcbind testdeleteapps testembed testmakeexist testmenubar testmetrics testprop testsend}]]]
